==> haskell-persistent-sqlite-2.6.2-56-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-persistent-sqlite.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-sqlite
version: 2.6.2
id: persistent-sqlite-2.6.2-ANFCDJn73iM2dSHADzU2H2
key: persistent-sqlite-2.6.2-ANFCDJn73iM2dSHADzU2H2
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Backend for the persistent library using sqlite3.
description:
    This package includes a thin sqlite3 wrapper based on the direct-sqlite package, as well as the entire C library, so there are no system dependencies.
category: Database, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
indefinite: False
exposed-modules:
    Database.Persist.Sqlite Database.Sqlite
abi: 8dd7cdb7e5e4c7618d7905295e74f3c0
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/persistent-sqlite-2.6.2
library-dirs: /usr/lib/ghc-8.2.1/site-local/persistent-sqlite-2.6.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/persistent-sqlite-2.6.2
hs-libraries: HSpersistent-sqlite-2.6.2-ANFCDJn73iM2dSHADzU2H2
extra-libraries:
    pthread
depends:
    base-4.10.0.0 bytestring-0.10.8.2 transformers-0.5.2.0
    persistent-2.7.0-I8wmVXOMY0i6N2WQ58UsGf
    monad-control-1.0.2.2-IzU5oITMXX63Y9dO6OJIj containers-0.5.10.2
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    aeson-1.2.3.0-SQQydLO5BXKh1lJDeeNrq
    conduit-1.2.12.1-675zH3bb85ZA0Qb4jnuu4h
    monad-logger-0.3.25.1-CwaXwQJnYksLl9woJRYT1i
    microlens-th-0.4.1.1-LM8ksjmIHXtDJYY6zPs0W6
    resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9 time-1.8.0.2
    old-locale-1.0.0.7-1sqf81TERjR1yVX7sI2OtM
    resource-pool-0.2.3.2-Lvu8b2azqmPDyhUQPYb0gG
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             bytestring-0.10.8.2=590a7a3c0bdcf7a6a59d8c8ef548a44a
             transformers-0.5.2.0=2645d250dd615ce454f807270041c5ea
             persistent-2.7.0-I8wmVXOMY0i6N2WQ58UsGf=c53e1f43762e773eded8a5cc34ce4c32
             monad-control-1.0.2.2-IzU5oITMXX63Y9dO6OJIj=dfad8947f11740596f17fadd714d5078
             containers-0.5.10.2=dd4e66fa9ac268f47a15786f1100b042
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=9217a19661a41b462c62d1a4bdf2e9b1
             aeson-1.2.3.0-SQQydLO5BXKh1lJDeeNrq=66a2d17fbbc7a6e96ce7fb88add84f33
             conduit-1.2.12.1-675zH3bb85ZA0Qb4jnuu4h=6bf0cea2ccec20058d527d53a4f54166
             monad-logger-0.3.25.1-CwaXwQJnYksLl9woJRYT1i=ae71fa24f4a725ec3254a0c142a3f528
             microlens-th-0.4.1.1-LM8ksjmIHXtDJYY6zPs0W6=2b9b417729fa558909a86809bf4d3c1c
             resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9=5151457a381efe5b858f660d93294781
             time-1.8.0.2=e9c7416c5b79f57513fe11898c3d9f95
             old-locale-1.0.0.7-1sqf81TERjR1yVX7sI2OtM=8abc34d96a58625e2975ccc02aacab97
             resource-pool-0.2.3.2-Lvu8b2azqmPDyhUQPYb0gG=7045beb6d85d0b408839717a807445b4
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=f561664cdb04511e569f0d44c9086d8e
haddock-interfaces: /usr/share/doc/haskell-persistent-sqlite/html/persistent-sqlite.haddock
haddock-html: /usr/share/doc/haskell-persistent-sqlite/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-sqlite-2.6.3.1-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-persistent-sqlite.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-sqlite
version: 2.6.3.1
id: persistent-sqlite-2.6.3.1-CuHgHkbF8IHHBJVqmzTvBW
key: persistent-sqlite-2.6.3.1-CuHgHkbF8IHHBJVqmzTvBW
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Backend for the persistent library using sqlite3.
description:
    This package includes a thin sqlite3 wrapper based on the direct-sqlite package, as well as the entire C library, so there are no system dependencies.
category: Database, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
indefinite: False
exposed-modules:
    Database.Persist.Sqlite Database.Sqlite
abi: 4135c80f2f3ba5f2144674aa3bcbe8de
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/persistent-sqlite-2.6.3.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/persistent-sqlite-2.6.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/persistent-sqlite-2.6.3.1
hs-libraries: HSpersistent-sqlite-2.6.3.1-CuHgHkbF8IHHBJVqmzTvBW
extra-libraries:
    pthread sqlite3
depends:
    base-4.10.0.0 bytestring-0.10.8.2 transformers-0.5.2.0
    persistent-2.7.1-5rmtUTby7kSGSKF597S8Jy
    monad-control-1.0.2.2-IzU5oITMXX63Y9dO6OJIj containers-0.5.10.2
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    aeson-1.2.3.0-SQQydLO5BXKh1lJDeeNrq
    conduit-1.2.12.1-675zH3bb85ZA0Qb4jnuu4h
    monad-logger-0.3.25.1-6UjEl6EQeds1mtR2hwOxFY
    microlens-th-0.4.1.1-LM8ksjmIHXtDJYY6zPs0W6
    resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9 time-1.8.0.2
    old-locale-1.0.0.7-1sqf81TERjR1yVX7sI2OtM
    resource-pool-0.2.3.2-Lvu8b2azqmPDyhUQPYb0gG
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             bytestring-0.10.8.2=590a7a3c0bdcf7a6a59d8c8ef548a44a
             transformers-0.5.2.0=2645d250dd615ce454f807270041c5ea
             persistent-2.7.1-5rmtUTby7kSGSKF597S8Jy=480425e15ad28d0c90708eef2da49b85
             monad-control-1.0.2.2-IzU5oITMXX63Y9dO6OJIj=dfad8947f11740596f17fadd714d5078
             containers-0.5.10.2=dd4e66fa9ac268f47a15786f1100b042
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=9217a19661a41b462c62d1a4bdf2e9b1
             aeson-1.2.3.0-SQQydLO5BXKh1lJDeeNrq=66a2d17fbbc7a6e96ce7fb88add84f33
             conduit-1.2.12.1-675zH3bb85ZA0Qb4jnuu4h=6bf0cea2ccec20058d527d53a4f54166
             monad-logger-0.3.25.1-6UjEl6EQeds1mtR2hwOxFY=5743c547d6758f34a133a7bec2ee753a
             microlens-th-0.4.1.1-LM8ksjmIHXtDJYY6zPs0W6=2b9b417729fa558909a86809bf4d3c1c
             resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9=5151457a381efe5b858f660d93294781
             time-1.8.0.2=e9c7416c5b79f57513fe11898c3d9f95
             old-locale-1.0.0.7-1sqf81TERjR1yVX7sI2OtM=8abc34d96a58625e2975ccc02aacab97
             resource-pool-0.2.3.2-Lvu8b2azqmPDyhUQPYb0gG=7045beb6d85d0b408839717a807445b4
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=f561664cdb04511e569f0d44c9086d8e
haddock-interfaces: /usr/share/doc/haskell-persistent-sqlite/html/persistent-sqlite.haddock
haddock-html: /usr/share/doc/haskell-persistent-sqlite/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
